@@ -1088,6 +1088,59 @@ clutter_script_parser_parse_end (JsonParser *parser)
   clutter_script_ensure_objects (CLUTTER_SCRIPT_PARSER (parser)->script);
 }
 
+gboolean
+_clutter_script_parse_translatable_string (ClutterScript *script,
+                                           JsonNode      *node,
+                                           char         **str)
+{
+  JsonObject *obj;
+  const char *string, *domain, *context;
+  const char *res;
+  gboolean translatable;
+
+  if (!JSON_NODE_HOLDS_OBJECT (node))
+    return FALSE;
+
+  obj = json_node_get_object (node);
+  if (!(json_object_has_member (obj, "translatable") &&
+        json_object_has_member (obj, "string")))
+    return FALSE;
+
+  translatable = json_object_get_boolean_member (obj, "translatable");
+
+  string = json_object_get_string_member (obj, "string");
+  if (string == NULL || *string == '\0')
+    return FALSE;
+
+  if (json_object_has_member (obj, "context"))
+    context = json_object_get_string_member (obj, "context");
+  else
+    context = NULL;
+
+  if (json_object_has_member (obj, "domain"))
+    domain = json_object_get_string_member (obj, "domain");
+  else
+    domain = NULL;
+
+  if (domain == NULL || *domain == '\0')
+    domain = clutter_script_get_translation_domain (script);
+
+  if (translatable)
+    {
+      if (context != NULL && *context != '\0')
+        res = g_dpgettext2 (domain, context, string);
+      else
+        res = g_dgettext (domain, string);
+    }
+  else
+    res = string;
+
+  if (str != NULL)
+    *str = g_strdup (res);
+
+  return TRUE;
+}
+
 gboolean
 _clutter_script_parse_node (ClutterScript *script,
                             GValue        *value,
@@ -1095,7 +1148,7 @@ _clutter_script_parse_node (ClutterScript *script,
                             JsonNode      *node,
                             GParamSpec    *pspec)
 {
-  GValue node_value = { 0, };
+  GValue node_value = G_VALUE_INIT;
   gboolean retval = FALSE;
 
   g_return_val_if_fail (CLUTTER_IS_SCRIPT (script), FALSE);
@@ -1203,6 +1256,16 @@ _clutter_script_parse_node (ClutterScript *script,
                   return TRUE;
                 }
             }
+          else if (p_type == G_TYPE_STRING)
+            {
+              char *str = NULL;
+
+              if (_clutter_script_parse_translatable_string (script, node, &str))
+                {
+                  g_value_take_string (value, str);
+                  return TRUE;
+                }
+            }
          }
       return FALSE;
 
@@ -1604,7 +1667,7 @@ apply_layout_properties (ClutterScript    *script,
   for (l = properties; l != NULL; l = l->next)
     {
       PropertyInfo *pinfo = l->data;
-      GValue value = { 0, };
+      GValue value = G_VALUE_INIT;
       gboolean res = FALSE;
       const gchar *name;
 
@@ -1704,7 +1767,7 @@ apply_child_properties (ClutterScript    *script,
   for (l = properties; l != NULL; l = l->next)
     {
       PropertyInfo *pinfo = l->data;
-      GValue value = { 0, };
+      GValue value = G_VALUE_INIT;
       gboolean res = FALSE;
       const gchar *name;
 
